summaryrefslogtreecommitdiff
path: root/gnu/packages
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/packages')
-rw-r--r--gnu/packages/emacs-xyz.scm6
1 files changed, 3 insertions, 3 deletions
diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index 83b52c7f220..8441449e4ea 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -38699,7 +38699,7 @@ all of your projects, then override or add variables on a per-project basis.")
(define-public emacs-casual
(package
(name "emacs-casual")
- (version "2.11.2")
+ (version "2.13.1")
(source
(origin
(method git-fetch)
@@ -38708,7 +38708,7 @@ all of your projects, then override or add variables on a per-project basis.")
(commit version)))
(file-name (git-file-name name version))
(sha256
- (base32 "10hdhpgsxhvyi6ybcvlfhwm88q34sgsb43jvgg7m4jm98n1nvima"))))
+ (base32 "1qgrraffmgxhcqdsi1x4xy0byp758khk69xyr68cllap5xnmdhgc"))))
(build-system emacs-build-system)
(arguments
(list
@@ -38717,7 +38717,7 @@ all of your projects, then override or add variables on a per-project basis.")
(add-after 'unpack 'build-info-manual
(lambda _
;; FIXME: Re-generating documentation is not possible at the
;; moment (release 2.11.2) because the "casual" Texinfo class is
;; missing from the repository, and this prevents Org from
;; exporting properly the "casual.org" file to Texinfo.
;;
@@ -38717,7 +38717,7 @@ all of your projects, then override or add variables on a per-project basis.")
(lambda _
;; FIXME: Re-generating documentation is not possible at the
- ;; moment (release 2.11.2) because the "casual" Texinfo class is
+ ;; moment (release 2.13.1) because the "casual" Texinfo class is
;; missing from the repository, and this prevents Org from
;; exporting properly the "casual.org" file to Texinfo.